mix compile.module_indexer (NFTables v0.8.2)

Custom Mix compiler that generates NFTables.ExprIndex module.

This compiler runs after the standard Elixir compiler and:

  1. Queries all compiled modules in the :nftables application
  2. Filters for modules matching NFTables.Expr.* prefix
  3. Generates and compiles NFTables.ExprIndex with all() function

The generated module is used by the use NFTables macro to dynamically import all expression building modules.

Summary

Functions

Cleans up generated files.

Runs the module indexer compiler.

Functions

clean()

Cleans up generated files.

run(args)

Runs the module indexer compiler.

Returns:

  • {:ok, []} on success with changes
  • {:noop, []} when no changes detected