mix compile.module_indexer (NFTables v0.8.2)
View SourceCustom Mix compiler that generates NFTables.ExprIndex module.
This compiler runs after the standard Elixir compiler and:
- Queries all compiled modules in the :nftables application
- Filters for modules matching NFTables.Expr.* prefix
- Generates and compiles NFTables.ExprIndex with all() function
The generated module is used by the use NFTables macro to
dynamically import all expression building modules.